# Authors

## Design and main code development

- Ammar Hakim (PPPL) <ahakim@pppl.gov>
- Petr Cagas (HZDR/CASUS) <p.cagas@hzdr.de>

## Contributors (ultra alphabetically)

- Manaure Francisquez (PPPL)
- Luca Georgescu
- Jonathan Gorard (PPPL)
- James Juno (PPPL)
- Noah Mandel (PPPL)
- Maxwell Rosen (PPPL)
- Liang Wang

## Acknowledgement

- Bhuvana Srinivasan (UW)
- Jason TenBarge (PU)
